@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -112,12 +112,11 @@ public class SubscriptionSession implements Session {
         throw new UnsupportedOperationException();
     }
 
-    public void removeUploadedFileOnly(final String id) {
-        throw new UnsupportedOperationException();
-    }
-
     public void setParameter(final String name, final Object value) {
         throw new UnsupportedOperationException();        
     }
 
+    public String getAuthId() {
+        throw new UnsupportedOperationException();
+    }
 }
