@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -174,7 +174,7 @@ public class DocumentMetadataHolderFolderUpdaterStrategy implements FolderUpdate
             return null;
         }
         try {
-            return HTTPToolkit.grabStream(newElement.dataLink);
+            return HTTPToolkit.grabStream(newElement.dataLink, false);
         } catch (IOException e) {
             LOG.debug(e.getMessage(), e);
         }
