@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -500,8 +500,10 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
             throw new SubscriptionException(e);
         } finally {
             try {
-                writeConnection.rollback();
-                writeConnection.setAutoCommit(true);
+                if(writeConnection != null) {
+                    writeConnection.rollback();
+                    writeConnection.setAutoCommit(true);
+                }
             } catch (SQLException e) {
                 throw SQLException.create(e);
             }
@@ -533,8 +535,10 @@ public class SubscriptionSQLStorage implements SubscriptionStorage {
             throw SQLException.create(e);
         } finally {
             try {
-                writeConnection.rollback();
-                writeConnection.setAutoCommit(true);
+                if(writeConnection != null) {
+                    writeConnection.rollback();
+                    writeConnection.setAutoCommit(true);
+                }
             } catch (SQLException e) {
                 throw SQLException.create(e);
             }
